@@ -23,17 +23,6 @@ The following are objects that are expected to be stored in this namespace:
 
 =over
 
-=cut
-
-our $User = {};
-
-=item User
-
-Stores a LedgerSMB::User object for the currently logged in user.
-
-=cut
-
-
 =item DBH
 
 Database handle for current connection
@@ -53,22 +42,6 @@ the variables above given a "my" scope instead of an "our" one.
 
 =over
 
-=item User
-
-=cut
-
-sub User {
-    return $User;
-}
-
-=item set_User
-
-=cut
-
-sub set_User {
-    return $User = shift;
-}
-
 =item DBH
 
 =cut
@@ -100,11 +73,7 @@ sub run_with_state {
     my $block = shift;
     my $state = { @_ };
 
-    local ($DBH, $User) = (
-        $state->{DBH} // $DBH,
-        $state->{User} // $User,
-        );
-
+    local $DBH = $state->{DBH} // $DBH;
     return $block->();
 }
 
