@@ -121,14 +121,14 @@ sub reset_password {
    return;
 }
 
-=item create
+=item create( $password, [ \%prefs ] )
 
 Creates the new user.
 
 =cut
 
 sub create {
-    my ($self, $password) = @_;
+    my ($self, $password, $prefs) = @_;
     my ($ref) = $self->call_dbmethod(
         funcname => 'admin__save_user',
         args => { password => $password });
@@ -138,6 +138,18 @@ sub create {
             funcname => 'admin__add_user_to_role',
             args => [ $self->username, $role ]);
     }
+    $prefs //= {};
+    my $query = <<~'SQL';
+       insert into
+           user_preference (user_id, name, value)
+           values ($1, $2, $3)
+       SQL
+    my $sth = $self->dbh->prepare($query)
+        or die $self->dbh->errstr;
+    for my $pref (keys $prefs->%*) {
+        $sth->execute($self->id, $pref, $prefs->{$pref})
+            or die $sth->errstr;
+    }
     return;
 }
 
