@@ -14,14 +14,14 @@ The type behaves internally as a Datetime module.
 
 =cut
 
-use strict;
+use v5.36;
 use warnings;
 use base qw(PGObject::Type::DateTime);
+use Scalar::Util qw(blessed);
 
 use Carp;
 use DateTime::Format::Strptime qw(strptime);
 
-use LedgerSMB::App_State;
 use LedgerSMB::Magic
     qw( MONTHS_PER_QUARTER YEARS_PER_CENTURY FUTURE_YEARS_LIMIT );
 
@@ -104,7 +104,7 @@ sub add_interval {
     );
     my $delta_name = $delta_names{$interval};
     #Validate asked interval
-    die "Bad interval: $interval" if not defined $delta_name;
+    croak "Bad interval: $interval" if not defined $delta_name;
 
     $n //= 1;    # Default to 1
     $n *= MONTHS_PER_QUARTER if $interval eq 'quarter'; # A quarter is 3 months
@@ -152,18 +152,17 @@ my $fb_parser =  DateTime::Format::Strptime->new(
 
 
 sub from_input{
-    my ($self, $input) = @_;
-
-    local $@ = undef;
-    return $input if eval {$input->isa(__PACKAGE__)} && $input->is_date;
+    my $self = shift;
+    my $input = shift;
 
+    return $input if blessed $input and $input->isa( __PACKAGE__ ) and $input->is_date;
     return __PACKAGE__->new()
         if ! $input; # matches undefined as well as ''
 
     my $dt = $pref_parser->parse_datetime($input)
         // $fb_parser->parse_datetime($input);
 
-    die "Bad timestamp ($input)" if $input && ! $dt;
+    croak "Bad timestamp ($input)" if $input && ! $dt;
     bless $dt, __PACKAGE__;
     $dt->is_date(1);
     $dt->is_time(($input && $input =~ /\:/) ? 1 : 0); # Define time
@@ -179,30 +178,29 @@ used.  If $format is not supplied, the dateformat of the user is used.
 =cut
 
 sub to_output {
-    my ($self) = @_;
+    my $self = shift @_;
     return '' if not $self->is_date();
-    my $fmt;
-    if (defined LedgerSMB::App_State::User()->{dateformat}){
-        $fmt = LedgerSMB::App_State::User()->{dateformat};
-    } else {
-        $fmt = '%F';
-    }
-    $fmt = $formats->{uc($fmt)} if defined $formats->{uc($fmt)};
+    my %args  = (ref($_[0]) eq 'HASH')? %{$_[0]}: @_;
 
-    $fmt .= ' %T' if $self->is_time();
-    $fmt =~ s/^\s+//;
+    my $fmt = $args{format} // $args{datetimeformat};
+    if (not defined $fmt) {
+        $fmt = $args{dateformat} // '%F';
+        $fmt = $formats->{uc($fmt)} if defined $formats->{uc($fmt)};
+
+        $fmt .= ' %T' if $self->is_time();
+        $fmt =~ s/^\s+//;
+    }
 
     # the hard-coded 'en_US' locale here is no problem: it's used
     # for the %b format ('mon') to look up the names of the months;
     # however, we only support numeric formats
     my $formatter = DateTime::Format::Strptime->new(
-             pattern => $fmt,
-              locale => 'en_US',
-            on_error => 'croak',
-    );
-    my $date = $formatter->format_datetime($self);
-    if ($date =~ /\:/ and not $self->is_time()) { die 'to_output'; }
-    return $date;
+        pattern  => $fmt,
+        locale   => 'en_US',
+        on_error => 'croak',
+        );
+
+    return $formatter->format_datetime($self);;
 }
 
 =item $self->to_sort()
