@@ -41,6 +41,13 @@ Boolean, true if it is a gifi report.
 
 has gifi => (is => 'rw', isa => 'Bool');
 
+=item from_date
+=item to_date
+
+Dates come from LedgerSMB::Report::Dates
+
+=cut
+
 =item legacy_hierarchy
 
 Boolean, true if the regular hierarchies need to be ignored,
@@ -153,14 +160,16 @@ sub run_report {
 
 
     my $col_id = $self->cheads->map_path($self->column_path_prefix);
+    my $_from_date = $self->from_date->to_output($self->{formatter_options});
+    my $_to_date = $self->to_date->to_output($self->{formatter_options});
     $self->cheads->id_props($col_id,
                             { description =>
                                   $self->Text(
                                       "[_1]\n[_2]",
-                                      $self->from_date->to_output,
-                                      $self->to_date->to_output),
-                              from_date => $self->from_date->to_output,
-                              to_date => $self->to_date->to_output,
+                                      $_from_date,
+                                      $_to_date),
+                              from_date => $_from_date,
+                              to_date => $_to_date
                             });
 
     for my $line (@lines) {
