@@ -253,6 +253,9 @@ sub lookup {
     my %values;
     @values{keys %{$m->[MAP_NAMES]}} =
         @segments[values %{$m->[MAP_NAMES]}] if $m->[MAP_NAMES];
+    for my $named_value (values %values) {
+        return undef unless length $named_value > 0;
+    }
 
     if (wantarray) {
         return ($m->[MAP_HANDLER], \%values, \@wild, $m->[MAP_PATHDEF]);
@@ -397,16 +400,16 @@ Add web service API request/response validation wrapper around the code
 reference. Returns the path and a code reference which can be used as the
 argument list of the api entry point defining keywords:
 
-  post api 'our/path/' => sub {
+  post api '/our/path' => sub {
      my ($env, $req, $company, $body, $params, @rest) = @_;
      ...;
   };
 
 The wrapper wants the C<api_schema> setting to be assigned in order to
-be able to validate the validity of the request and the response.
+be able to validate the request and the response.
 
-In case third element of the PSGI triplet is undefined or the return value
-itself is undefined, a C<404 Not Found> response is generated.
+In case the third element of the PSGI triplet is undefined or the return
+value itself is undefined, a C<404 Not Found> response is generated.
 
 The parameters to the coderef are:
 
@@ -477,7 +480,8 @@ sub api {
             my $schema = $settings->api_validator;
             my $req = Plack::Request::WithEncoding->new($env);
             my $has_body = ($req->headers->content_length() // 0) > 0;
-            my $body = ($req->headers->content_type eq 'application/json') ?
+            my $content_type = $has_body ? $req->headers->content_type : '';
+            my $body = ($has_body and $content_type eq 'application/json') ?
                 json()->decode($req->content) : '';
             # bug: multipart/form-data wants to be validated and
             # so does application/x-www-form-urlencoded
@@ -490,16 +494,16 @@ sub api {
                         path => $params,
                         header => { $req->headers->psgi_flatten->@* },
                         query => $req->query_parameters->as_hashref_mixed,
-                        body => [ $has_body, $req->headers->content_type, $body ]
+                        body => [ $has_body, $content_type, $body ]
                     });
             if (scalar(@$errors) > 0) {
                 my ($err) = @$errors;
                 if ($err->context and
                     $err->context->[0]->message =~ m/content with content-type/) {
-                    return error($req, HTTP_UNSUPPORTED_MEDIA_TYPE, [], @$errors);
+                    return _error($req, HTTP_UNSUPPORTED_MEDIA_TYPE, [], @$errors);
                 }
 
-                return error($req, HTTP_BAD_REQUEST, [], @$errors);
+                return _error($req, HTTP_BAD_REQUEST, [], @$errors);
             }
 
             my $company = LedgerSMB::Company->new(dbh => $env->{'lsmb.app'});
@@ -512,9 +516,9 @@ sub api {
                     [ 'Not found' ] ];
             }
 
-            $has_body = reftype $triplet->[2] ne 'ARRAY'
+            my $has_return_body = reftype $triplet->[2] ne 'ARRAY'
                 or Plack::Util::content_length($triplet->[2]);
-            my $content_type =
+            my $return_content_type =
                 ((Plack::Util::header_get($triplet->[1], 'Content-Type') // '')
                  =~ s/;(.*)$//r);
             ($result, $errors, $warnings) =
@@ -526,9 +530,9 @@ sub api {
                         header => { $triplet->[1]->@* },
                         path => $params,
                         query => $req->query_parameters->as_hashref_mixed,
-                        body => [ $has_body, $content_type, $triplet->[2] ]
+                        body => [ $has_return_body, $return_content_type, $triplet->[2] ]
                     });
-            return error($req, HTTP_INTERNAL_SERVER_ERROR, [], @$errors)
+            return _error($req, HTTP_INTERNAL_SERVER_ERROR, [], @$errors)
                 if scalar(@$errors) > 0;
 
             $triplet->[2] = [ json()->encode($triplet->[2]) ]
@@ -591,18 +595,26 @@ $body
 |;
     }
     else {
-        $text = json()->encode({ error => 1,
-                                 msg => 'LedgerSMB API errors',
-                                 errors => \@errors });
+        $text = { error => 1,
+                  msg => 'LedgerSMB API errors',
+                  errors => \@errors };
     }
     return [
         $code,
         [ 'Content-Type' => ($result_type eq 'html'
                              ? 'text/html' : 'application/json') ],
-        [ $text ]
+        $text
         ];
 }
 
+sub _error {
+    my $triplet = error(@_);
+    $triplet->[2] = [ json()->encode($triplet->[2]) ]
+        if (Plack::Util::header_get($triplet->[1], 'Content-Type') // '') =~ m|^application/json|;
+
+    return $triplet;
+}
+
 sub hook {
     my ($name, $hook) = @_;
 
