@@ -99,7 +99,9 @@ sub _get_pricegroup {
 sub _get_pricegroups {
     my ($c, $formatter) = @_;
     my $sth = $c->dbh->prepare(
-        q|SELECT id, pricegroup as description FROM pricegroup ORDER BY id|
+        q|SELECT id, pricegroup as description,
+                 md5(last_updated::text) as etag
+          FROM pricegroup ORDER BY id|
         ) or die $c->dbh->errstr;
 
     $sth->execute() or die $sth->errstr;
@@ -108,6 +110,7 @@ sub _get_pricegroups {
         push @results, {
             id => $row->{id},
             description => $row->{description},
+            _meta => { ETag => $row->{etag} }
         };
     }
     die $sth->errstr if $sth->err;
@@ -164,7 +167,7 @@ get api '/products/pricegroups' => sub {
             _dbh => $c->dbh,
             language => 'en',
             );
-        my $renderer = $formatter->report_doc_renderer( $c->dbh, $format );
+        my $renderer = $formatter->report_doc_renderer( $c->dbh, {}, $format );
 
         return template_response( $report->render( renderer => $renderer ),
                                   disposition => 'attach');
@@ -311,7 +314,7 @@ sub _get_warehouse {
 sub _get_warehouses {
     my ($c, $formatter) = @_;
     my $sth = $c->dbh->prepare(
-        q|SELECT * FROM warehouse ORDER BY id|
+        q|SELECT *, md5(last_updated::text) as etag FROM warehouse ORDER BY id|
         ) or die $c->dbh->errstr;
 
     $sth->execute() or die $sth->errstr;
@@ -320,6 +323,7 @@ sub _get_warehouses {
         push @results, {
             id => $row->{id},
             description => $row->{description},
+            _meta => { ETag => $row->{etag} }
         };
     }
     die $sth->errstr if $sth->err;
@@ -377,7 +381,7 @@ get api '/products/warehouses' => sub {
             _dbh => $c->dbh,
             language => 'en',
             );
-        my $renderer = $formatter->report_doc_renderer( $c->dbh, $format );
+        my $renderer = $formatter->report_doc_renderer( $c->dbh, {}, $format );
 
         return template_response( $report->render( renderer => $renderer ),
                                   disposition => 'attach');
@@ -499,8 +503,9 @@ paths:
                     type: array
                     items:
                       $ref: '#/components/schemas/Pricegroup'
-                    example:
-                      $ref: '#/components/examples/validPricegroup'
+              examples:
+                validPricegroups:
+                  $ref: '#/components/examples/validPricegroups'
         400:
           $ref: '#/components/responses/400'
         401:
@@ -680,8 +685,8 @@ paths:
                     items:
                       $ref: '#/components/schemas/Warehouse'
               examples:
-                validWarehouse:
-                  $ref: '#/components/examples/validWarehouse'
+                validWarehouses:
+                  $ref: '#/components/examples/validWarehouses'
         400:
           $ref: '#/components/responses/400'
         401:
@@ -878,12 +883,28 @@ components:
         description:
           type: string
   examples:
+    validPricegroups:
+      summary: Valid pricegroups (collection response)
+      description: Pricegroups collection response
+      value:
+        _links: []
+        items:
+        - id: 1
+          description: Pricegroup1
     validPricegroup:
       summary: Valid Pricegroup
       description: Pricegroup entry
       value:
         id: 1
         description: Pricegroup1
+    validWarehouses:
+      summary: Valid warehouses (collection response)
+      description: Warehouses collection response
+      value:
+        _links: []
+        items:
+        - id: 1
+          description: Warehouse1
     validWarehouse:
       summary: Valid Warehouse
       description: Warehouse entry
