@@ -11,8 +11,9 @@ Budget workflow scripts.
 
 =cut
 
-use strict;
+use v5.36;
 use warnings;
+use Scalar::Util qw(blessed);
 
 use LedgerSMB::Budget;
 use LedgerSMB::Business_Unit;
@@ -75,7 +76,7 @@ sub _render_screen {
         $budget->lines($lines);
     }
     $budget->error('Invalid object')
-         unless $budget->isa('LedgerSMB::Budget');
+         unless blessed $budget and $budget->isa('LedgerSMB::Budget');
     # The button logic is kinda complicated here.  The basic idea is that there
     # are three stages in the handling of the budget:  Initial entry, review and
     # approval, and review with the possibility of obsolescence.
