@@ -156,8 +156,14 @@ sub list_drafts {
 
     $request->open_form;
     return $request->render_report(
-        LedgerSMB::Report::Unapproved::Drafts->new(%$request)
-        );
+        LedgerSMB::Report::Unapproved::Drafts->new(
+            $request->%{ qw( reference type language _locale ) },
+            formatter_options => $request->formatter_options,
+            from_date => $request->parse_date( $request->{from_date} ),
+            to_date => $request->parse_date( $request->{to_date} ),
+            amount_gt => $request->parse_amount( $request->{amount_gt} ),
+            amount_lt => $request->parse_amount( $request->{amount_lt} ),
+        ));
 }
 
 
