@@ -149,7 +149,6 @@ sub del {
         ->fetch_workflow( 'AR/AP', $form->{workflow_id} );
     $wf->execute_action( 'del' );
 
-    $form->call_procedure(funcname=>'draft_delete', args => [ $form->{id} ]);
     $form->info($locale->text('Draft deleted'));
 }
 
@@ -369,7 +368,9 @@ sub create_links {
                 $form->{"$form->{ARAP}_paid_$i"} =
 "$form->{acc_trans}{$key}->[$i-1]->{accno}--$form->{acc_trans}{$key}->[$i-1]->{description}";
                 $form->{"paid_$i"} =
-                  $form->{acc_trans}{$key}->[ $i - 1 ]->{amount} * -1 * $ml;
+                    $form->{acc_trans}{$key}->[ $i - 1 ]->{amount} * -1 * $ml;
+                $form->{"paid_${i}_approved"} =
+                    $form->{acc_trans}{$key}->[ $i - 1 ]->{approved};
                 $form->{"datepaid_$i"} =
                   $form->{acc_trans}{$key}->[ $i - 1 ]->{transdate};
                 $form->{"source_$i"} =
@@ -456,11 +457,6 @@ sub create_links {
     $form->{rowcount}++ if ( $form->{id} || !$form->{rowcount} );
     $form->{rowcount} = 1 unless $form->{"$form->{ARAP}_amount_1"};
 
-    # readonly
-    if ( !$form->{readonly} ) {
-        $form->{readonly} = 1
-          if $myconfig{acs} && $myconfig{acs} =~ /$form->{ARAP}--Add Transaction/;
-    }
     delete $form->{selectcurrency};
     #$form->generate_selects(\%myconfig);
     $form->{$form->{ARAP}} = $form->{"$form->{ARAP}_1"} unless $form->{$form->{ARAP}} and $form->{__action} eq 'update';
@@ -600,7 +596,7 @@ qq|<textarea data-dojo-type="dijit/form/Textarea" name=intnotes rows=$rows cols=
       ( $form->{"select$form->{vc}"} )
       ? qq|<select data-dojo-type="lsmb/FilteringSelect" id="$form->{vc}" name="$form->{vc}" $readonly><option></option>$form->{"select$form->{vc}"}</select>|
       : qq|<input data-dojo-type="dijit/form/TextBox" id="$form->{vc}" name="$form->{vc}" value="$form->{$form->{vc}}" size=35 $readonly>
-                 <a href="erp.pl?__action=root#contact.pl?__action=add&entity_class=$eclass"
+                 <a href="#contact.pl?__action=add&entity_class=$eclass"
                     id="new-contact" target="_blank">[|
                  .  $locale->text('New') . qq|]</a>|;
 
@@ -726,7 +722,7 @@ $form->open_status_div($status_div_id) . qq|
             <tr>
         <th align="right" nowrap>| .
             $locale->text('Entity Control Code') . qq|</th>
-        <td colspan=3><a href="erp.pl?__action=root#contact.pl?__action=get_by_cc&control_code=$form->{entity_control_code}" target="_blank"><b>$form->{entity_control_code}</b></a></td>
+        <td colspan=3><a href="#contact.pl?__action=get_by_cc&control_code=$form->{entity_control_code}" target="_blank"><b>$form->{entity_control_code}</b></a></td>
           </tr>
             <tr>
         <th align="right" nowrap>| .
@@ -979,12 +975,13 @@ qq|<td><input data-dojo-type="dijit/form/TextBox" name="description_$i" size=40
 |;
 
     if ( $form->{currency} eq $form->{defaultcurrency} ) {
-        @column_index = qw(datepaid source memo paid ARAP_paid);
+        @column_index = qw(status datepaid source memo paid ARAP_paid);
     }
     else {
-        @column_index = qw(datepaid source memo paid exchangerate paidfx ARAP_paid);
+        @column_index = qw(status datepaid source memo paid exchangerate paidfx ARAP_paid);
     }
 
+    $column_data{status}       = "<th></th>";
     $column_data{datepaid}     = "<th>" . $locale->text('Date') . "</th>";
     $column_data{paid}         = "<th>" . $locale->text('Amount') . "</th>";
     $column_data{exchangerate} = "<th>" . $locale->text('Exch') . "</th>";
@@ -1015,8 +1012,13 @@ qq|<td><input data-dojo-type="dijit/form/TextBox" name="description_$i" size=40
 
         $form->hide_form("cleared_$i");
 
-        print q|
-        <tr class="invoice-payment">
+        my ($title, $approval_status, $icon) =
+            ($form->{approved} and $form->{"paid_${i}_approved"}) ? ('', 'approved', '')
+            : $form->{"datepaid_$i"} ? ($locale->text('Pending approval'), 'unapproved', '&#x23F2;')
+            : ('', '', '');
+        $title = qq|title="$title"| if $title;
+        print qq|
+        <tr class="invoice-payment $approval_status" $title>
 |;
 
         $form->{"select$form->{ARAP}_paid_$i"} =
@@ -1052,6 +1054,8 @@ qq|<input data-dojo-type="dijit/form/TextBox" name="exchangerate_$i" size=10 val
         $form->{"datepaid_$i"} //= '';
         $form->{"source_$i"} //= '';
         $form->{"memo_$i"} //= '';
+
+        $column_data{status} = qq|<td style="text-align:center;vertical-align:middle">$icon</td>|;
         $column_data{paid} =
 qq|<td align=center><input data-dojo-type="dijit/form/TextBox" name="paid_$i" id="paid_$i" size=11 value=$form->{"paid_$i"} $readonly></td>|;
         $column_data{ARAP_paid} =
@@ -1302,8 +1306,6 @@ sub on_hold {
 # }
 
 sub edit_and_save {
-    $form->call_procedure(funcname=>'draft_delete', args => [ $form->{id} ]);
-    delete $form->{id};
     AA->post_transaction( \%myconfig, \%$form );
 
     if ($form->{workflow_id}) {
@@ -1317,7 +1319,6 @@ sub edit_and_save {
 }
 
 sub approve {
-    $form->update_invnumber;
     $form->call_procedure(funcname=>'draft_approve', args => [ $form->{id} ]);
 
     my $wf = $form->{_wire}->get('workflows')
@@ -1459,6 +1460,7 @@ sub update {
 
 sub post_and_approve {
     post();
+    $form->call_procedure(funcname=>'draft_approve', args => [ $form->{id} ]);
 }
 
 sub post {
