@@ -137,7 +137,7 @@ sub display_taxes {
         ( $null, $i ) = split /_/, $_;
 
         $form->{"taxrate_$i"} =
-          $form->format_amount( \%myconfig, $form->{"taxrate_$i"}, $form->{_setting_decimal_places}, '0');
+          $form->format_amount( \%myconfig, $form->{"taxrate_$i"});
 
         $hiddens{"taxdescription_$i"} = $form->{"taxdescription_$i"};
         $hiddens{"old_validto_$i"} = $form->{"old_validto_$i"};
@@ -543,8 +543,8 @@ sub process_transactions {
             # forward to removing this code. --CT
             for ( keys %$form ) { delete $form->{$_}; }
             for (qw(header dbversion company dbh login path sessionid _auth
-                    stylesheet timeout id _locale _wire _req)
-            ) {
+                    stylesheet timeout id _locale _wire _req _user)
+                ) {
                 $form->{$_} = $pt->{$_};
             }
             # post, print, email
@@ -709,6 +709,15 @@ sub process_transactions {
                     }
                     $form->info( " ..... " . $locale->text('done') );
 
+                    # posting the transaction above changed the workflow
+                    # as stored on disk; update the workflow stored in
+                    # memory. Also, we can't use the "post_and_approve"
+                    # action because that's only available when
+                    # "separate_duties" *isn't* enabled, so execute 2 actions
+                    # which are guaranteed to exist, separately
+                    $wf = $form->{_wire}->get('workflows')->fetch_workflow(
+                        'AR/AP',
+                        $form->{workflow_id} );
                     # Make sure the transaction isn't posted as a draft
                     $wf->execute_action( 'post' )
                         if $wf->state eq 'INITIAL';
@@ -852,6 +861,16 @@ sub process_transactions {
                       )
                 );
                 $ok = GL->post_transaction( \%myconfig, \%$form, $locale );
+
+                # posting the transaction above changed the workflow
+                # as stored on disk; update the workflow stored in
+                # memory. Also, we can't use the "post_and_approve"
+                # action because that's only available when
+                # "separate_duties" *isn't* enabled, so execute 2 actions
+                # which are guaranteed to exist, separately
+                $wf = $form->{_wire}->get('workflows')->fetch_workflow(
+                    'GL',
+                    $form->{workflow_id} );
                 # Make sure the transaction isn't posted as a draft
                 $wf->execute_action( 'post' )
                     if $wf->state eq 'INITIAL';
