@@ -56,15 +56,13 @@ Deprecated
 
 package Form;
 
-use strict;
+use v5.36;
 use charnames qw(:full);
 use open ':utf8';
 use utf8;
-
+use Scalar::Util qw( blessed );
 
 use LedgerSMB;
-use LedgerSMB::App_State;
-use LedgerSMB::Company_Config;
 use LedgerSMB::Magic qw( SCRIPT_OLDSCRIPTS );
 use LedgerSMB::PGNumber;
 use LedgerSMB::Setting::Sequence;
@@ -515,7 +513,6 @@ sub redirect {
     my ( $self, $msg ) = @_;
 
     if ( $self->{callback} || !$msg ) {
-        $logger->trace("Full redirect \$self->{callback}=$self->{callback} \$msg=$msg");
         $self->_redirect();
         $self->finalize_request();
     }
@@ -528,9 +525,8 @@ sub redirect {
 
 sub _redirect {
     # referenced directly from am.pl, because of the need of our return value
-    use List::Util qw(first);
     my ($self) = @_;
-    my ( $script, $argv ) = split( /\?/, $self->{callback}, 2 );
+    my ( $script, $argv ) = split( /\?/, $self->{callback} // '', 2 );
 
     if ( !$script ) {    # http redirect to login.pl if called w/no args
         print "Location: login.pl\n";
@@ -703,13 +699,12 @@ sub format_amount {
     $amount = "" unless defined $amount;
     $places = "0" unless defined $places;
     $dash = "" unless defined $dash;
-    $amount = $self->parse_amount($myconfig, $amount);
     if ($self->{money_precision}){
        $places= $self->{money_precision};
     }
-    $myconfig->{numberformat} = '1000.00' unless $myconfig->{numberformat};
     $amount = $self->parse_amount( $myconfig, $amount )
         unless ref($amount) eq 'LedgerSMB::PGNumber';
+    $myconfig->{numberformat} = '1000.00' unless $myconfig->{numberformat};
     return $amount->to_output({
                places => $places,
                 money => $self->{money_precision},
@@ -718,6 +713,14 @@ sub format_amount {
     });
 }
 
+sub formatter_options {
+    my ( $self ) = @_;
+
+    return {
+        $self->{_user}->%{ qw( dateformat numberformat ) }
+    };
+}
+
 =item $form->parse_amount($myconfig, $amount);
 
 Return a LedgerSMB::PGNumber containing the value of $amount where $amount is
@@ -730,18 +733,40 @@ Calls $form->error if the value is NaN.
 =cut
 
 sub parse_amount {
-
     my ( $self, $myconfig, $amount ) = @_;
-    local $@;
-    return $amount if eval {$amount->isa('LedgerSMB::PGNumber') };
 
+    return $amount if (blessed $amount
+                       and $amount->isa( 'LedgerSMB::PGNumber' ));
     if ( ( ! defined $amount ) or ( $amount eq '' ) ) {
         $amount = '0';
     }
 
     return LedgerSMB::PGNumber->from_input(
         $amount,
-                                           {format => $myconfig->{numberformat}}
+        { format => $myconfig->{numberformat} }
+    );
+}
+
+=item $form->parse_date($myconfig, $date);
+
+Return a LedgerSMB::PGDate containing the value of $date where $date is
+formatted as $myconfig->{dateformat}.  If $date is '' or undefined, undef
+is returned.
+
+=cut
+
+sub parse_date {
+    my ( $self, $myconfig, $date ) = @_;
+
+    return $date if (blessed $date
+                     and $date->isa( 'LedgerSMB::PGDate' ));
+    if ( ( ! defined $date ) or ( $date eq '' ) ) {
+        $date = '';
+    }
+
+    return LedgerSMB::PGDate->from_input(
+        $date,
+        { format => $myconfig->{dateformat} }
     );
 }
 
@@ -1205,8 +1230,6 @@ sub db_init {
 
     $self->{dbh} = $dbh;
     _set_datestyle($dbh);
-
-    LedgerSMB::Company_Config::initialize($self->{dbh});
 }
 
 sub _set_datestyle {
@@ -1284,7 +1307,7 @@ sub update_balance {
 =item $form->add_shipto($id, $is_oe);
 
 Inserts a new location_id reference into the table new_shipto, using the
-Form->{locationid} property.
+Form->{shiptolocationid} property.
 
 $is_oe determines whether the locaation is linked with a transaction or an oe.
 
@@ -1300,32 +1323,27 @@ sub add_shipto {
         return;
     }
 
-    my $query = qq|
-            INSERT INTO new_shipto
-            (trans_id, oe_id,location_id)
-            VALUES ( ?, ?, ?)
-            |;
-
-        my $sth = $self->{dbh}->prepare($query) || $self->dberror($query);
-        my $trans_id;
-        my $oe_id;
-
     if ($is_oe) {
-           $trans_id = undef;
-           $oe_id = $id;
+        $self->{dbh}->do('update oe set shipto = ? where id = ?',
+                         {},
+                         $self->{shiptolocationid},
+                         $id)
+            or die $self->{dbh}->errstr;
+    }
+    elsif ($self->{vc} eq 'customer') {
+        $self->{dbh}->do('update ar set shipto = ? where id = ?',
+                         {},
+                         $self->{shiptolocationid},
+                         $id)
+            or die $self->{dbh}->errstr;
     }
     else {
-           $trans_id = $id;
-           $oe_id = undef;
-        }
-
-        $sth->execute(
-                        $trans_id,
-            $oe_id,
-            $self->{shiptolocationid}
-              ) || $self->dberror($query);
-
-    $sth->finish;
+        $self->{dbh}->do('update ap set shipto = ? where id = ?',
+                         {},
+                         $self->{shiptolocationid},
+                         $id)
+            or die $self->{dbh}->errstr;
+    }
 }
 
 =item $form->get_shipto ($location_id)
@@ -1976,7 +1994,8 @@ sub create_links {
                 c.language_code, a.ponumber, a.reverse,
                 a.approved, ctf.default_reportable,
                 a.description, a.on_hold, a.crdate,
-                ns.location_id as locationid, a.is_return, $seq,
+                a.shipto as shiptolocationid, a.shipto_attn as shiptoattn,
+                a.is_return, $seq,
                 t.workflow_id, t.reversing, t.reversing_reference,
                 t.reversed_by, t.reversed_by_reference
             FROM $arap a
@@ -1987,9 +2006,8 @@ sub create_links {
             LEFT JOIN entity_employee er
                                    ON (er.entity_id = a.person_id)
             LEFT JOIN entity e ON (er.entity_id = e.id)
-                        LEFT JOIN country_tax_form ctf
+            LEFT JOIN country_tax_form ctf
                                   ON (ctf.id = c.taxform_id)
-                        LEFT JOIN new_shipto ns on a.id = ns.trans_id
             WHERE a.id = ? AND c.entity_class =
                 (select id FROM entity_class
                 WHERE class ilike ?)|;
@@ -2081,7 +2099,8 @@ sub create_links {
                                 array_agg(ARRAY[bul.class_id, bul.bu_id])
                                 AS bu_lines,
                (exists (select 1 from payment_links pl
-                         where a.entry_id = pl.entry_id)) AS payment_line
+                         where a.entry_id = pl.entry_id)) AS payment_line,
+               approved
             FROM acc_trans a
             JOIN account c ON (c.id = a.chart_id)
                    LEFT JOIN business_unit_ac bul ON a.entry_id = bul.entry_id
@@ -2978,24 +2997,6 @@ sub should_update_defaults {
     return 0;
 }
 
-=item $form->update_invnumber
-
-If invnumber is not set, updates it.  Used when gapless numbering is in effect
-
-=cut
-
-sub update_invnumber {
-    my $self = shift;
-    my $query =
-        q|update ar
-             set invnumber = setting_increment('sinumber')
-           where id = ? and invnumber is null|;
-    $self->{dbh}->do($query,
-                     {},
-                     $self->{id})
-        or $self->dberror($query);
-}
-
 =item $form->db_prepare_vars(var1, var2, ..., varI<n>)
 
 Undefines $form->{varI<m>}, 1 <= I<m> <= I<n>, iff $form-<{varI<m> is both
