@@ -21,7 +21,6 @@ use strict;
 use warnings;
 
 use base 'PGObject::Simple';
-use LedgerSMB::Sysconfig;
 
 =head1 METHODS
 
@@ -50,6 +49,11 @@ sub new {
     return $self;
 }
 
+sub funcschema {
+    my $self = shift;
+    return $self->dbh->{private_LedgerSMB}->{schema};
+}
+
 =back
 
 =cut
