@@ -24,6 +24,13 @@ CREATE TYPE tax_form_report_item AS (
     meta_number character varying(32),
     tax_id text,
     sales_tax_id text,
+    line_one text,
+    line_two text,
+    line_three text,
+    city text,
+    state text,
+    mail_code text,
+    country_id integer,
     acc_sum numeric,
     invoice_sum numeric,
     total_sum numeric);
@@ -38,6 +45,13 @@ CREATE TYPE tax_form_report_detail_item AS (
     meta_number character varying(32),
     tax_id text,
     sales_tax_id text,
+    line_one text,
+    line_two text,
+    line_three text,
+    city text,
+    state text,
+    mail_code text,
+    country_id integer,
     acc_sum numeric,
     invoice_sum numeric,
     total_sum numeric,
@@ -53,6 +67,8 @@ RETURNS SETOF tax_form_report_item AS $BODY$
                      entity_credit_account.entity_class, entity.control_code,
                      entity_credit_account.meta_number,
                      company.tax_id, company.sales_tax_id,
+                     addr.line_one, addr.line_two, addr.line_three,
+                     addr.city, addr.state, addr.mail_code, addr.country_id,
                      sum(CASE WHEN gl.amount_bc = 0 THEN 0
                               WHEN relation = 'acc_trans'
                           THEN ac.reportable_amount_bc * pmt.amount_bc
@@ -72,18 +88,23 @@ RETURNS SETOF tax_form_report_item AS $BODY$
                       * CASE WHEN ac.relation = 'invoice' then -1 else 1 end)
 
                 FROM (select id, transdate, entity_credit_account, invoice,
-                             amount_bc, 'ar' as class FROM ar
+                             amount_bc, 'ar' as class
+                        FROM ar
+                       WHERE approved
                        UNION
                       select id, transdate, entity_credit_account, invoice,
-                              amount_bc, 'ap' as class from ap
+                             amount_bc, 'ap' as class
+                        FROM ap
+                       WHERE approved
                      ) gl
                JOIN (select trans_id, 'acc_trans' as relation,
                              sum(amount_bc) as amount_bc,
                              sum(case when atf.reportable then amount_bc else 0
                                  end) as reportable_amount_bc
-                        FROM  acc_trans
+                       FROM  acc_trans
                     LEFT JOIN ac_tax_form atf
                           ON (acc_trans.entry_id = atf.entry_id)
+                      WHERE acc_trans.approved
                        GROUP BY trans_id
                        UNION
                       select trans_id, 'invoice' as relation,
@@ -105,10 +126,11 @@ RETURNS SETOF tax_form_report_item AS $BODY$
                              array_agg(chart_id) as chart_ids,
                              count(*) as num
                         FROM acc_trans ac
-                       where chart_id in (select account_id
+                       WHERE approved
+                         AND chart_id in (select account_id
                                             from account_link
                                            where description like '%paid')
-                          AND transdate BETWEEN in_from_date AND in_to_date
+                         AND transdate BETWEEN in_from_date AND in_to_date
                      group by ac.trans_id
                      ) pmt ON  (pmt.trans_id = gl.id)
                 JOIN entity_credit_account
@@ -116,8 +138,40 @@ RETURNS SETOF tax_form_report_item AS $BODY$
                 JOIN entity ON (entity.id = entity_credit_account.entity_id)
                 JOIN company ON (entity.id = company.entity_id)
                 JOIN country_tax_form ON (entity_credit_account.taxform_id = country_tax_form.id)
-               WHERE country_tax_form.id = in_tax_form_id
-             GROUP BY legal_name, meta_number, company.tax_id, company.sales_tax_id, company.entity_id, entity_credit_account.entity_class, entity.control_code, entity_credit_account.id
+  LEFT JOIN LATERAL (
+    SELECT * FROM (
+      select * from (
+        -- entity_credit_account.id ensures a 1-1 join with the left side
+        select entity_credit_account.id as eca_id, l.*
+          from eca_to_location eca2l
+                 join location_class lc on lc.id = eca2l.location_class
+                 join location l on l.id = eca2l.location_id
+         where eca2l.credit_id = entity_credit_account.id -- this is the LATERAL!
+           and lc.authoritative
+         order by lc.id, eca2l.created
+      ) y
+       union all
+      select * from (
+        -- entity_credit_account.id ensures a 1-1 join with the left side
+        -- and due to the join on the left side,
+        -- entity_credit_account.entity_id = entity.id
+        select entity_credit_account.id, l.*
+          from entity_to_location e2l
+                 join location_class lc on lc.id = e2l.location_class
+                 join location l on l.id = e2l.location_id
+         where e2l.entity_id = entity.id -- this is the LATERAL!
+           and lc.authoritative
+         order by lc.id, e2l.created
+      ) z
+    ) x
+    LIMIT 1
+  ) addr ON addr.eca_id = entity_credit_account.id
+  WHERE country_tax_form.id = in_tax_form_id
+  GROUP BY legal_name, meta_number, company.tax_id, company.sales_tax_id, company.entity_id,
+           entity_credit_account.entity_class, entity.control_code, entity_credit_account.id,
+           addr.line_one, addr.line_two, addr.line_three, addr.city, addr.state,
+           addr.mail_code, addr.country_id;
+
 $BODY$ LANGUAGE SQL;
 
 COMMENT ON FUNCTION tax_form_summary_report
@@ -133,6 +187,8 @@ RETURNS SETOF tax_form_report_detail_item AS $BODY$
                      entity_credit_account.entity_class, entity.control_code,
                      entity_credit_account.meta_number,
                      company.tax_id, company.sales_tax_id,
+                     addr.line_one, addr.line_two, addr.line_three,
+                     addr.city, addr.state, addr.mail_code, addr.country_id,
                      sum(CASE WHEN gl.amount_bc = 0 then 0
                               when relation = 'acc_trans'
                           THEN ac.reportable_amount_bc * pmt.amount_bc
@@ -155,10 +211,12 @@ RETURNS SETOF tax_form_report_detail_item AS $BODY$
                 FROM (select id, entity_credit_account, invnumber, duedate,
                              amount_bc, transdate, 'ar' as class
                         FROM ar
+                       WHERE approved
                        UNION
                       select id, entity_credit_account, invnumber, duedate,
                              amount_bc, transdate, 'ap' as class
                         FROM ap
+                       WHERE approved
                      ) gl
                 JOIN (select trans_id, 'acc_trans' as relation,
                              sum(amount_bc) as amount_bc,
@@ -167,6 +225,7 @@ RETURNS SETOF tax_form_report_detail_item AS $BODY$
                         FROM  acc_trans
                    LEFT JOIN ac_tax_form atf
                           ON (acc_trans.entry_id = atf.entry_id)
+                       WHERE acc_trans.approved
                        GROUP BY trans_id
                        UNION
                       select trans_id, 'invoice' as relation,
@@ -189,14 +248,43 @@ RETURNS SETOF tax_form_report_detail_item AS $BODY$
                              array_agg(chart_id) as chart_ids,
                              count(*) as num
                         FROM acc_trans ac
-                       where chart_id in (select account_id
+                       WHERE approved
+                         AND chart_id in (select account_id
                                             from account_link
                                            where description like '%paid')
                           AND transdate BETWEEN in_from_date AND in_to_date
                      group by ac.trans_id
                      ) pmt ON  (pmt.trans_id = gl.id)
+  LEFT JOIN LATERAL (
+    SELECT * FROM (
+      select * from (
+      select entity_credit_account.entity_id, l.*
+        from eca_to_location eca2l
+               join location_class lc on lc.id = eca2l.location_class
+               join location l on l.id = eca2l.location_id
+       where eca2l.credit_id = entity_credit_account.id -- this is the LATERAL!
+         and lc.authoritative
+       order by lc.id, eca2l.created
+      ) y
+       union all
+      select * from (
+      select entity.id, l.*
+        from entity_to_location e2l
+               join location_class lc on lc.id = e2l.location_class
+               join location l on l.id = e2l.location_id
+       where e2l.entity_id = entity.id -- this is the LATERAL!
+         and lc.authoritative
+       order by lc.id, e2l.created
+      ) z
+    ) x
+    LIMIT 1
+  ) addr ON addr.entity_id = entity.id
                 WHERE country_tax_form.id = in_tax_form_id AND meta_number = in_meta_number
-                GROUP BY legal_name, meta_number, company.entity_id, company.tax_id, company.sales_tax_id, entity_credit_account.entity_class, entity.control_code, gl.invnumber, gl.duedate, gl.id, entity_credit_account.id
+  GROUP BY legal_name, meta_number, company.tax_id, company.sales_tax_id, company.entity_id,
+           entity_credit_account.entity_class, entity.control_code, entity_credit_account.id,
+           addr.line_one, addr.line_two, addr.line_three, addr.city, addr.state,
+           addr.mail_code, addr.country_id,
+           gl.invnumber, gl.duedate, gl.id
 $BODY$ LANGUAGE SQL;
 
 COMMENT ON FUNCTION tax_form_details_report
@@ -214,6 +302,8 @@ RETURNS SETOF tax_form_report_item AS $BODY$
                      entity_credit_account.entity_class, entity.control_code,
                      entity_credit_account.meta_number,
                      company.tax_id, company.sales_tax_id,
+                     addr.line_one, addr.line_two, addr.line_three,
+                     addr.city, addr.state, addr.mail_code, addr.country_id,
                      sum(CASE WHEN gl.amount_bc = 0 THEN 0
                               WHEN relation = 'acc_trans'
                           THEN ac.reportable_amount_bc
@@ -230,20 +320,25 @@ RETURNS SETOF tax_form_report_item AS $BODY$
                       * CASE WHEN ac.relation = 'invoice' then -1 else 1 end)
 
                 FROM (select id, transdate, entity_credit_account, invoice,
-                             amount_bc, 'ar' as class FROM ar
-                       WHERE transdate BETWEEN in_from_date AND in_to_date
+                             amount_bc, 'ar' as class
+                        FROM ar
+                       WHERE approved
+                         AND transdate BETWEEN in_from_date AND in_to_date
                        UNION
                       select id, transdate, entity_credit_account, invoice,
-                              amount_bc, 'ap' as class from ap
-                       WHERE transdate BETWEEN in_from_date AND in_to_date
+                             amount_bc, 'ap' as class
+                        FROM ap
+                       WHERE approved
+                         AND transdate BETWEEN in_from_date AND in_to_date
                      ) gl
                JOIN (select trans_id, 'acc_trans' as relation,
                              sum(amount_bc) as amount_bc,
                              sum(case when atf.reportable then amount_bc else 0
                                  end) as reportable_amount_bc
-                        FROM  acc_trans
+                       FROM  acc_trans
                     LEFT JOIN ac_tax_form atf
                           ON (acc_trans.entry_id = atf.entry_id)
+                      WHERE acc_trans.approved
                        GROUP BY trans_id
                        UNION
                       select trans_id, 'invoice' as relation,
@@ -265,8 +360,32 @@ RETURNS SETOF tax_form_report_item AS $BODY$
                 JOIN entity ON (entity.id = entity_credit_account.entity_id)
                 JOIN company ON (entity.id = company.entity_id)
                 JOIN country_tax_form ON (entity_credit_account.taxform_id = country_tax_form.id)
-               WHERE country_tax_form.id = in_tax_form_id
-             GROUP BY legal_name, meta_number, company.entity_id, company.tax_id, company.sales_tax_id, entity_credit_account.entity_class, entity.control_code, entity_credit_account.id
+  LEFT JOIN LATERAL (
+    SELECT * FROM (
+      select * from (
+      select entity_credit_account.entity_id, l.* from eca_to_location eca2l
+                        join location_class lc on lc.id = eca2l.location_class
+                        join location l on l.id = eca2l.location_id
+       where eca2l.credit_id = entity_credit_account.id and lc.authoritative
+       order by lc.id, eca2l.created
+      ) y
+       union all
+      select * from (
+      select entity.id, l.* from entity_to_location e2l
+                        join location_class lc on lc.id = e2l.location_class
+                        join location l on l.id = e2l.location_id
+       where e2l.entity_id = entity.id and lc.authoritative
+       order by lc.id, e2l.created
+      ) z
+    ) x
+    LIMIT 1
+  ) addr ON addr.entity_id = entity.id
+  WHERE country_tax_form.id = in_tax_form_id
+  GROUP BY legal_name, meta_number, company.tax_id, company.sales_tax_id, company.entity_id,
+           entity_credit_account.entity_class, entity.control_code, entity_credit_account.id,
+           addr.line_one, addr.line_two, addr.line_three, addr.city, addr.state,
+           addr.mail_code, addr.country_id;
+
 $BODY$ LANGUAGE SQL;
 
 COMMENT ON FUNCTION tax_form_summary_report_accrual
@@ -283,6 +402,8 @@ RETURNS SETOF tax_form_report_detail_item AS $BODY$
                      entity_credit_account.entity_class, entity.control_code,
                      entity_credit_account.meta_number,
                      company.tax_id, company.sales_tax_id,
+                     addr.line_one, addr.line_two, addr.line_three,
+                     addr.city, addr.state, addr.mail_code, addr.country_id,
                      sum(CASE WHEN gl.amount_bc = 0 then 0
                               when relation = 'acc_trans'
                           THEN ac.reportable_amount_bc
@@ -303,20 +424,23 @@ RETURNS SETOF tax_form_report_detail_item AS $BODY$
                 FROM (select id, entity_credit_account, invnumber, duedate,
                              amount_bc, transdate, 'ar' as class
                         FROM ar
-                       WHERE transdate BETWEEN in_from_date AND in_to_date
+                       WHERE approved
+                         AND transdate BETWEEN in_from_date AND in_to_date
                        UNION
                       select id, entity_credit_account, invnumber, duedate,
                              amount_bc, transdate, 'ap' as class
                         FROM ap
-                       WHERE transdate BETWEEN in_from_date AND in_to_date
+                       WHERE approved
+                         AND transdate BETWEEN in_from_date AND in_to_date
                      ) gl
                 JOIN (select trans_id, 'acc_trans' as relation,
                              sum(amount_bc) as amount_bc,
                              sum(case when atf.reportable then amount_bc else 0
                                  end) as reportable_amount_bc
                         FROM  acc_trans
-                   LEFT JOIN ac_tax_form atf
+                             LEFT JOIN ac_tax_form atf
                           ON (acc_trans.entry_id = atf.entry_id)
+                       WHERE acc_trans.approved
                        GROUP BY trans_id
                        UNION
                       select trans_id, 'invoice' as relation,
@@ -334,8 +458,32 @@ RETURNS SETOF tax_form_report_detail_item AS $BODY$
                 JOIN entity ON (entity.id = entity_credit_account.entity_id)
                 JOIN company ON (entity.id = company.entity_id)
                 JOIN country_tax_form ON (entity_credit_account.taxform_id = country_tax_form.id)
-                WHERE country_tax_form.id = in_tax_form_id AND meta_number = in_meta_number
-                GROUP BY legal_name, meta_number, company.entity_id, company.tax_id, company.sales_tax_id, entity_credit_account.entity_class, entity.control_code, gl.invnumber, gl.duedate, gl.id, entity_credit_account.id
+  LEFT JOIN LATERAL (
+    SELECT * FROM (
+      select * from (
+      select entity_credit_account.entity_id, l.* from eca_to_location eca2l
+                        join location_class lc on lc.id = eca2l.location_class
+                        join location l on l.id = eca2l.location_id
+       where eca2l.credit_id = entity_credit_account.id and lc.authoritative
+       order by lc.id, eca2l.created
+      ) y
+       union all
+      select * from (
+      select entity.id, l.* from entity_to_location e2l
+                        join location_class lc on lc.id = e2l.location_class
+                        join location l on l.id = e2l.location_id
+       where e2l.entity_id = entity.id and lc.authoritative
+       order by lc.id, e2l.created
+      ) z
+    ) x
+    LIMIT 1
+  ) addr ON addr.entity_id = entity.id
+  WHERE country_tax_form.id = in_tax_form_id AND meta_number = in_meta_number
+  GROUP BY legal_name, meta_number, company.tax_id, company.sales_tax_id, company.entity_id,
+           entity_credit_account.entity_class, entity.control_code, entity_credit_account.id,
+           addr.line_one, addr.line_two, addr.line_three, addr.city, addr.state,
+           addr.mail_code, addr.country_id,
+           gl.invnumber, gl.duedate, gl.id
 $BODY$ LANGUAGE SQL;
 
 COMMENT ON FUNCTION tax_form_details_report_accrual
