@@ -60,8 +60,9 @@ LANGUAGE SQL AS $$
         WHERE o.oe_class_id = in_oe_class_id
              AND (in_meta_number IS NULL
                    or ct.meta_number ILIKE in_meta_number || '%')
-             AND (in_legal_name IS NULL OR
-                     c.name @@ plainto_tsquery(in_legal_name))
+             AND (in_legal_name IS NULL
+                  OR c.name ilike '%' || in_legal_name || '%'
+                  OR c.name @@ plainto_tsquery(in_legal_name))
              AND (in_ponumber IS NULL OR o.ponumber ILIKE in_ponumber || '%')
              AND (in_ordnumber IS NULL
                   OR (oe_class_id IN (1, 2) AND o.ordnumber ILIKE in_ordnumber || '%')
